@@ -1,7 +1,10 @@
 from importlib import import_module
+from arkitekt.cli.types import Manifest
 from arkitekt.utils import create_arkitekt_folder
 from pydantic import BaseModel, Field
-
+import sys
+import rich_click as click
+from enum import Enum
 
 try:
     from rekuest.api.schema import DefinitionInput
@@ -9,34 +12,33 @@ try:
 except ImportError as e:
     raise ImportError("Please install rekuest to use this feature") from e
 
-    
+
 import os
-from typing import List
+from typing import List, Optional
 import yaml
 import json
 import datetime
 
+from subprocess import check_call
+
+
 def import_deployer(builder):
     module_path, function_name = builder.rsplit(".", 1)
     module = import_module(module_path)
     function = getattr(module, function_name)
     return function
 
-def generate_definitions(module_path) -> List[DefinitionInput]:
 
+def generate_definitions(module_path) -> List[DefinitionInput]:
     import_module(module_path)
     reg = get_default_definition_registry()
     return list(reg.definitions.keys())
 
 
-class Deployment(BaseModel):
-    identifier: str
-    version: str
-    deployer: str = "arkitekt.deployers.port.dockerbuild"
-    builder: str
+class Deployment(Manifest):
     definitions: List[DefinitionInput]
-    scopes: List[str] = []
-    deployed: dict
+    image: str
+    command: Optional[str]
     deployed_at: datetime.datetime = Field(default_factory=datetime.datetime.now)
 
 
@@ -45,38 +47,63 @@ class ConfigFile(BaseModel):
     latest_deployment: datetime.datetime = Field(default_factory=datetime.datetime.now)
 
 
+class DockerFile(BaseModel):
+    base: Optional[str] = None
+    commands: List[str] = Field(default_factory=list)
 
 
-
-
-
-def generate_deployment(identifier: str, version: str, module_path: str, deployed: dict, deployer: str,  scopes: List[str], with_definitions = True, builder: str = "arkitekt.builders.port") -> Deployment:
-
+def load_deployments() -> ConfigFile:
     path = create_arkitekt_folder()
+    config_file = os.path.join(path, "deployments.yaml")
+    if os.path.exists(config_file):
+        with open(config_file, "r") as file:
+            return ConfigFile(**yaml.safe_load(file))
+    else:
+        return ConfigFile()
 
 
+def check_if_manifest_already_deployed(manifest: Manifest):
+    config = load_deployments()
+    for deployment in config.deployments:
+        if (
+            deployment.identifier == manifest.identifier
+            and deployment.version == manifest.version
+        ):
+            raise click.ClickException(
+                f"Deployment of {manifest.identifier}/{manifest.version} already exists. You cannot deploy the same version twice."
+            )
+
+
+def generate_deployment(
+    manifest: Manifest,
+    image: str,
+    command: Optional[str],
+    with_definitions=True,
+) -> Deployment:
+    path = create_arkitekt_folder()
+
     config_file = os.path.join(path, "deployments.yaml")
 
-    definitions = generate_definitions(module_path) if with_definitions else []
-
-    deployment = Deployment(identifier=identifier, version=version, deployer=deployer, definitions=definitions, deployed=deployed, scopes=scopes, builder=builder)
-
+    definitions = generate_definitions("app") if with_definitions else []
 
+    deployment = Deployment(
+        **manifest.dict(),
+        definitions=definitions,
+        image=image,
+        command=command,
+    )
 
     if os.path.exists(config_file):
         with open(config_file, "r") as file:
             config = ConfigFile(**yaml.safe_load(file))
-            for existing_deployment in config.deployments:
-                if existing_deployment.identifier == identifier and existing_deployment.version == version:
-                    raise FileExistsError(f"This deployment already exists: {identifier}:{version}. Please upgrade your version number.")
-
             config.deployments.append(deployment)
             config.latest_deployment = datetime.datetime.now()
     else:
         config = ConfigFile(deployments=[deployment])
 
     with open(config_file, "w") as file:
-        yaml.safe_dump(json.loads(config.json(exclude_none=True, exclude_unset=True)), file, sort_keys=True)
-
-
-
+        yaml.safe_dump(
+            json.loads(config.json(exclude_none=True, exclude_unset=True)),
+            file,
+            sort_keys=True,
+        )
